---
title: Overview
---

# Structure Overview

This document provides a guide for how documentation is structured in Nexmo Developer.

## How should I structure documents?

Nexmo Developer content should be designed to be clear, concise and consistent in that order.

Exceptions can be made to break consistency where it makes sense, particularly in scenarios where the content would be unnecessarily verbose or the structures outlined in this guide are unsuited to the material.

![Code Snippets](/assets/images/contributing/structure.png)

## Structure

Nexmo Developer is structured by context and by product. The four main sections of Nexmo Developer are:

1. Documentation
2. API References
3. SDKs and Tools
4. Community

### Documentation

This section hosts the bulk of the written content for the NDP. The content is structured by products each of which have the following four sections:

  * **[Overviews](/contribute/structure/content-types/overviews)** - The first pages you reach when you select a product.
  * **[Guides](/contribute/structure/content-types/guides)** - Provide key concepts in more depth than the overview.
  * **[Code Snippets](/contribute/structure/content-types/code-snippets)** - Used as a quick reference of how to do something specific.
  * **[Tutorials](/contribute/structure/content-types/tutorials)** - Step-by-step guide on how to do something. There is also a detailed [guide to tutorials](/contribute/guides/tutorials) available.
  * **[Use Cases](/contribute/structure/content-types/use-cases)** - Multi-product scenarios using Vonage APIs and those of other providers.

### API Reference

API Reference pages document the following properties of the API:

- Description
- Overview
- Resource Model
- Endpoints
  - URL
  - Method
  - Parameters
  - Response

### SDKs and Tools

A section that outlines our SDKs, Tools, Libraries etc. The repository README should provide all necessary information.

### Community

As it develops, the community section will be a repository for 'cool hacks', open source projects that use Nexmo, the events that Nexmo will attend or sponsor, and blog posts that the community has written about Nexmo.
